@@ -6,7 +6,7 @@ use crate::input::Input;
 use crate::scene::{BaseScene, NullSpawnable, Scene, SceneConfig, SceneType};
 #[cfg(feature = "audio")] use crate::audio::{AlAudio, Audio, AudioError, NullAudio};
 use crate::renderer::{Renderer, RendererError, ViewportMode, WindowScaleMode};
-#[cfg(feature = "imgui")] use crate::imgui_handler::ImGuiHandler;
+#[cfg(feature = "imgui_feature")] use crate::imgui_handler::ImGuiHandler;
 #[cfg(feature = "default_logger")] use crate::doglog;
 
 use sdl2::event::Event;
@@ -17,7 +17,7 @@ use sdl2::messagebox;
 #[cfg(feature = "graphical_panic")] use std::panic::PanicInfo;
 #[cfg(feature = "graphical_panic")] use backtrace::Backtrace;
 
-#[cfg(feature = "imgui")] use imgui;
+#[cfg(feature = "imgui_feature")] use imgui;
 
 use std::time::{Duration, Instant};
 use std::rc::Rc;
@@ -501,7 +501,7 @@ pub struct GameControl
     stats : GameStats,
     focused : bool,
     done : bool,
-    #[cfg(feature = "imgui")]
+    #[cfg(feature = "imgui_feature")]
     imgui_handler : Option<ImGuiHandler>
 }
 
@@ -568,7 +568,7 @@ impl GameControl
             controller_subsystem = None;
         }
 
-        #[cfg(feature = "imgui")]
+        #[cfg(feature = "imgui_feature")]
         let mut imgui_handler = ImGuiHandler::new().map_err(
             |error| InitError::ImguiInitError(error))?;
         
@@ -576,7 +576,7 @@ impl GameControl
         let mut renderer = Renderer::new(renderer_new_info).map_err(
             |error| InitError::RendererInitError(error))?;
         
-        #[cfg(feature = "imgui")]
+        #[cfg(feature = "imgui_feature")]
         renderer.control().init_imgui_renderer(imgui_handler.imgui_mut()).map_err(
             |error| InitError::RendererInitError(error))?;
 
@@ -605,7 +605,7 @@ impl GameControl
             focused : true,
             done : false,
             singletons : HashMap::new(),
-            #[cfg(feature = "imgui")]
+            #[cfg(feature = "imgui_feature")]
             imgui_handler : Some(imgui_handler),
         })
     }
@@ -695,7 +695,7 @@ impl GameControl
     }
 
     /// Retrieves the imgui context
-    #[cfg(feature = "imgui")]
+    #[cfg(feature = "imgui_feature")]
     pub fn imgui(&self) -> Option<&imgui::Context>
     {
         if let Some(imgui_handler) = &self.imgui_handler
@@ -707,7 +707,7 @@ impl GameControl
     }
 
     /// Retrieves the imgui context mutably
-    #[cfg(feature = "imgui")]
+    #[cfg(feature = "imgui_feature")]
     pub fn imgui_mut(&mut self) -> Option<&mut imgui::Context>
     {
         if let Some(imgui_handler) = &mut self.imgui_handler
@@ -823,7 +823,7 @@ struct GameloopTimeState
     cap_frametime : Duration,
     frame_start_jiffies : Duration,
     last_display : Instant,
-    #[cfg(feature = "imgui")]
+    #[cfg(feature = "imgui_feature")]
     last_imgui : Instant,
     lag_this_frame : u32,
     lag_this_second : u32,
@@ -853,7 +853,7 @@ impl GameloopTimeState
             cap_frametime : Duration::new(0, 0),
             frame_start_jiffies : Duration::new(0, 0),
             last_display : Instant::now(),
-            #[cfg(feature = "imgui")]
+            #[cfg(feature = "imgui_feature")]
             last_imgui : Instant::now(),
             lag_this_frame : 0,
             lag_this_second : 0,
@@ -1195,7 +1195,7 @@ impl Gameloop
     {
         self.time.draw_timer.begin_frame_timing();
 
-        #[cfg(feature = "imgui")]
+        #[cfg(feature = "imgui_feature")]
         {
             if !self.imgui_draw()
             {
@@ -1203,7 +1203,7 @@ impl Gameloop
             }
         }
 
-        #[cfg(not(feature = "imgui"))]
+        #[cfg(not(feature = "imgui_feature"))]
         self.scene_draw();
 
         if self.time.thought_yet && self.should_draw()
@@ -1233,7 +1233,7 @@ impl Gameloop
         }
     }
 
-    #[cfg(feature = "imgui")]
+    #[cfg(feature = "imgui_feature")]
     fn imgui_draw(&mut self) -> bool
     {
         let mut imgui_handler : Option<ImGuiHandler> = None;
@@ -1336,7 +1336,7 @@ impl Gameloop
     {
         self.control.low_energy_timer = 0;
 
-        #[cfg(feature = "imgui")]
+        #[cfg(feature = "imgui_feature")]
         {
             if let Some(imgui_handler) = &mut self.control.imgui_handler
             {
