@@ -43,10 +43,10 @@
 
 #[cfg(feature = "graphical_panic")] extern crate backtrace;
 
-#[cfg(feature = "imgui")] extern crate imgui;
-#[cfg(feature = "imgui")] extern crate imgui_sys;
-#[cfg(feature = "imgui")] extern crate imgui_glium_renderer;
-#[cfg(feature = "imgui")] #[macro_use] extern crate cstr_macro;
+#[cfg(feature = "imgui_feature")] extern crate imgui;
+#[cfg(feature = "imgui_feature")] extern crate imgui_sys;
+#[cfg(feature = "imgui_feature")] extern crate imgui_glium_renderer;
+#[cfg(feature = "imgui_feature")] #[macro_use] extern crate cstr_macro;
 
 extern crate failure;
 #[macro_use] extern crate failure_derive;
@@ -75,7 +75,7 @@ pub extern crate keeshond_datapack as datapack;
 pub mod crate_reexport;
 pub mod doglog;
 pub mod util;
-#[cfg(feature = "imgui")] mod imgui_handler;
+#[cfg(feature = "imgui_feature")] mod imgui_handler;
 #[cfg(feature = "audio")] pub extern crate keeshond_audio as audio;
 pub mod input;
 pub mod scene;
