@@ -10,7 +10,7 @@ use std::cell::RefCell;
 
 use serde::{Deserialize, Serialize};
 
-#[cfg(feature = "imgui")] use imgui;
+#[cfg(feature = "imgui_feature")] use imgui;
 
 use crate::datapack::{DataError, DataId, DataMultistore, DataObject, DataStore, PreparedStoreError, TrustPolicy};
 use crate::datapack::source::Source;
@@ -345,7 +345,7 @@ pub enum RendererError
     RendererInitFailed(String),
     #[fail(display = "Resource load failed: {}", _0)]
     LoadResourceFailed(String),
-    #[cfg(feature = "imgui")]
+    #[cfg(feature = "imgui_feature")]
     #[fail(display = "Imgui renderer failed: {}", _0)]
     ImguiRendererFailed(String)
 }
@@ -1052,7 +1052,7 @@ pub(crate) mod draw_control_private
 {
     use crate::datapack::{DataMultistore, DataStore, PreparedStoreError};
     use crate::renderer::{DrawControlResult, Shader, Sheet, ViewportMode, WindowScaleMode};
-    #[cfg(feature = "imgui")] use crate::renderer::RendererError;
+    #[cfg(feature = "imgui_feature")] use crate::renderer::RendererError;
 
     #[doc(hidden)]
     pub struct RendererNewInfo<'a>
@@ -1074,15 +1074,15 @@ pub(crate) mod draw_control_private
         fn new(renderer_new_info : &mut RendererNewInfo) -> DrawControlResult where Self : Sized;
         fn sync_sheet_store(&mut self, sheet_store : &mut DataStore<Sheet>) -> Result<(), PreparedStoreError>;
         fn sync_shader_store(&mut self, shader_store : &mut DataStore<Shader>) -> Result<(), PreparedStoreError>;
-        #[cfg(feature = "imgui")]
+        #[cfg(feature = "imgui_feature")]
         fn draw_imgui(&mut self, ui : imgui::Ui);
         fn recalculate_viewport(&mut self, base_width : f32, base_height : f32);
         fn start_drawing(&mut self);
         fn end_drawing(&mut self);
         fn present(&mut self);
-        #[cfg(feature = "imgui")]
+        #[cfg(feature = "imgui_feature")]
         fn init_imgui_renderer(&mut self, imgui : &mut imgui::Context) -> Result<(), RendererError>;
-        #[cfg(feature = "imgui")]
+        #[cfg(feature = "imgui_feature")]
         fn update_imgui_renderer(&mut self, imgui : &mut imgui::Context);
     }
 }
@@ -1145,7 +1145,7 @@ impl DrawControlBackend for NullDrawControl
         Ok(())
     }
 
-    #[cfg(feature = "imgui")]
+    #[cfg(feature = "imgui_feature")]
     #[allow(unused_variables)]
     fn draw_imgui(&mut self, ui : imgui::Ui) {}
     #[allow(unused_variables)]
@@ -1156,13 +1156,13 @@ impl DrawControlBackend for NullDrawControl
     fn end_drawing(&mut self) {}
     #[allow(unused_variables)]
     fn present(&mut self) {}
-    #[cfg(feature = "imgui")]
+    #[cfg(feature = "imgui_feature")]
     #[allow(unused_variables)]
     fn init_imgui_renderer(&mut self, imgui : &mut imgui::Context) -> Result<(), RendererError>
     {
         Ok(())
     }
-    #[cfg(feature = "imgui")]
+    #[cfg(feature = "imgui_feature")]
     #[allow(unused_variables)]
     fn update_imgui_renderer(&mut self, imgui : &mut imgui::Context) {}
 }
@@ -1324,13 +1324,13 @@ impl Renderer
         scene.draw(resources, &mut self.control, &first_transform, interpolation);
     }
 
-    #[cfg(feature = "imgui")]
+    #[cfg(feature = "imgui_feature")]
     pub(crate) fn update_imgui(&mut self, imgui : &mut imgui::Context)
     {
         self.control().update_imgui_renderer(imgui);
     }
 
-    #[cfg(feature = "imgui")]
+    #[cfg(feature = "imgui_feature")]
     pub(crate) fn draw_imgui(&mut self, ui : imgui::Ui, resources : &mut DataMultistore)
     {
         self.control().sync_sheet_store(&mut resources.store_mut())
