@@ -13,7 +13,7 @@ use generic_array::{GenericArray, sequence::GenericSequence};
 use generic_array::typenum::U1024;
 use typenum::Unsigned;
 
-#[cfg(feature = "imgui")]
+#[cfg(feature = "imgui_feature")]
 use imgui;
 
 use serde::{Serialize, Deserialize};
@@ -32,7 +32,7 @@ use crate::gameloop::GameControl;
 use crate::renderer::{DrawControl, DrawTransform};
 
 
-#[cfg(feature = "imgui")]
+#[cfg(feature = "imgui_feature")]
 use std::marker::PhantomData;
 
 type ComponentTypeMax = U1024;
@@ -286,7 +286,7 @@ pub trait DrawerSystem
     fn priority(&self) -> i32 { 0 }
 }
 
-#[cfg(feature = "imgui")]
+#[cfg(feature = "imgui_feature")]
 pub trait ImGuiSystem<T : SceneType + 'static>
 {
     #[allow(unused_variables)]
@@ -296,13 +296,13 @@ pub trait ImGuiSystem<T : SceneType + 'static>
     fn end(&mut self, args : ThinkerArgs<T>) {}
 }
 
-#[cfg(feature = "imgui")]
+#[cfg(feature = "imgui_feature")]
 struct NullImGuiSystem<T : SceneType + 'static>
 {
     _phantom : PhantomData<T>
 }
 
-#[cfg(feature = "imgui")]
+#[cfg(feature = "imgui_feature")]
 impl<T : SceneType + 'static> ImGuiSystem<T> for NullImGuiSystem<T>
 {
     #[allow(unused_variables)]
@@ -915,7 +915,7 @@ impl<C : Component + 'static> ComponentStore<C>
         }
     }
 
-    /// Sets the [FreezeFlags] for the [Component] of the given [Entity], deactivating the
+    /// Sets or unsets the [FreezeFlags] for the [Component] of the given [Entity], deactivating the
     ///  component if any flags are set.
     pub fn set_frozen(&mut self, entity : &Entity, freeze_flags : FreezeFlags, freeze : bool) -> bool
     {
@@ -931,7 +931,7 @@ impl<C : Component + 'static> ComponentStore<C>
         }
     }
 
-    /// Sets the [FreezeFlags] for the "n-th" [Component] in the store. The index
+    /// Sets or unsets the [FreezeFlags] for the "n-th" [Component] in the store. The index
     /// you use here should not be cached, as the components may move around in the store.
     ///  In most cases you should use [ComponentStore::set_frozen()] instead.
     pub fn set_frozen_nth(&mut self, index : usize, freeze_flags : FreezeFlags, freeze : bool) -> bool
@@ -1772,8 +1772,8 @@ impl<T : SceneType + 'static> SceneControl<T>
         entity
     }
 
-    /// Unsets the [FreezeFlags] for the given [Entity] and all its [Components](Component) after
-    ///  the current [ThinkerSystem::think()] finishes.
+    /// Sets or unsets the [FreezeFlags] for the given [Entity] and all its [Components](Component)
+    ///  after the current [ThinkerSystem::think()] finishes.
     pub fn set_entity_frozen_later(&mut self, entity : &Entity, freeze_flags : FreezeFlags, freeze : bool)
     {
         self.deferred_freezes.push((Entity::new(entity.id, entity.generation), freeze_flags, freeze));
@@ -1870,7 +1870,7 @@ pub struct SceneConfig<T : SceneType + 'static>
 {
     thinkers : Vec<Box<dyn ThinkerSystem<T>>>,
     drawers : Vec<Box<dyn DrawerSystem>>,
-    #[cfg(feature = "imgui")]
+    #[cfg(feature = "imgui_feature")]
     imgui : Option<Box<dyn ImGuiSystem<T>>>,
     store_factories : HashMap<TypeId, Box<dyn FnOnce() -> Box<dyn ComponentStoreBase>>>,
 }
@@ -1883,7 +1883,7 @@ impl<T : SceneType + 'static> SceneConfig<T>
         {
             thinkers: Vec::new(),
             drawers: Vec::new(),
-            #[cfg(feature = "imgui")]
+            #[cfg(feature = "imgui_feature")]
             imgui: None,
             store_factories : HashMap::new(),
         }
@@ -1903,7 +1903,7 @@ impl<T : SceneType + 'static> SceneConfig<T>
         self
     }
 
-    #[cfg(feature = "imgui")]
+    #[cfg(feature = "imgui_feature")]
     pub fn imgui<S : ImGuiSystem<T> + 'static>(&mut self, imgui : Option<S>) -> &mut Self
     {
         match imgui
@@ -1994,7 +1994,7 @@ pub trait BaseScene
     fn think(&mut self, game : &mut GameControl);
     /// Runs the draw logic. Ideally, processes all the [DrawerSystems](DrawerSystem) in this scene.
     fn draw(&mut self, resources : &DataMultistore, drawing : &mut Box<dyn DrawControl>, transform : &DrawTransform, interpolation : f32);
-    #[cfg(feature = "imgui")]
+    #[cfg(feature = "imgui_feature")]
     fn imgui_think(&mut self, ui : &mut imgui::Ui, game : &mut GameControl);
     /// Called to run initialization logic. Ideally, calls [ThinkerSystem::start()] on all the
     /// [ThinkerSystems](ThinkerSystem) in this scene.
@@ -2182,7 +2182,7 @@ pub struct Scene<T : SceneType + 'static>
     control : SceneControl<T>,
     thinker_systems : Vec<Box<dyn ThinkerSystem<T>>>,
     drawer_systems : Vec<Box<dyn DrawerSystem>>,
-    #[cfg(feature = "imgui")]
+    #[cfg(feature = "imgui_feature")]
     imgui_system : Box<dyn ImGuiSystem<T>>,
     init_done : bool,
     deinit_done : bool
@@ -2239,7 +2239,7 @@ impl<T : SceneType + 'static> BaseScene for Scene<T>
         {
             self.add_drawer_system(drawer);
         }
-        #[cfg(feature = "imgui")]
+        #[cfg(feature = "imgui_feature")]
         {
             if let Some(imgui_system) = config.imgui
             {
@@ -2271,7 +2271,7 @@ impl<T : SceneType + 'static> BaseScene for Scene<T>
 
         std::mem::swap(&mut list, &mut self.thinker_systems);
 
-        #[cfg(feature = "imgui")]
+        #[cfg(feature = "imgui_feature")]
         {
             self.imgui_system.start(ThinkerArgs
             {
@@ -2314,7 +2314,7 @@ impl<T : SceneType + 'static> BaseScene for Scene<T>
         
         std::mem::swap(&mut list, &mut self.thinker_systems);
 
-        #[cfg(feature = "imgui")]
+        #[cfg(feature = "imgui_feature")]
         {
             self.imgui_system.end(ThinkerArgs
             {
@@ -2355,7 +2355,7 @@ impl<T : SceneType + 'static> BaseScene for Scene<T>
         std::mem::swap(&mut list, &mut self.drawer_systems);
     }
     
-    #[cfg(feature = "imgui")]
+    #[cfg(feature = "imgui_feature")]
     fn imgui_think(&mut self, ui : &mut imgui::Ui, game : &mut GameControl)
     {
         if !self.init_done || self.deinit_done
@@ -2393,7 +2393,7 @@ impl<T : SceneType + 'static> Scene<T>
             control : SceneControl::<T>::new(),
             thinker_systems : Vec::new(),
             drawer_systems : Vec::new(),
-            #[cfg(feature = "imgui")]
+            #[cfg(feature = "imgui_feature")]
             imgui_system : Box::new(NullImGuiSystem { _phantom : PhantomData }),
             init_done : false,
             deinit_done : false,
@@ -2565,8 +2565,8 @@ impl<T : SceneType + 'static> Scene<T>
         self.control.spawn_control.deferred_adds.clear();
     }
 
-    /// Sets the [FreezeFlags] for every [Component] in the given [Entity], deactivating the
-    ///  components if any flags are set.
+    /// Sets or unsets the [FreezeFlags] for every [Component] in the given [Entity], deactivating
+    ///  the components if any flags are set.
     pub fn set_entity_frozen(&mut self, entity : &Entity, freeze_flags : FreezeFlags, freeze : bool) -> bool
     {
         if entity.id >= self.components.entity_records.len()
@@ -2633,7 +2633,7 @@ impl<T : SceneType + 'static> Scene<T>
         });
     }
     
-    #[cfg(feature = "imgui")]
+    #[cfg(feature = "imgui_feature")]
     pub fn set_imgui_system(&mut self, system : Box<dyn ImGuiSystem<T>>)
     {
         self.imgui_system = system;
